# coding: utf-8

"""
    Mentortools Chat API

    Mentortools service for chatting

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from chat_server_connector_v2.models.ai_assistant_goal_get import AiAssistantGoalGet

class TestAiAssistantGoalGet(unittest.TestCase):
    """AiAssistantGoalGet unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AiAssistantGoalGet:
        """Test AiAssistantGoalGet
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AiAssistantGoalGet`
        """
        model = AiAssistantGoalGet()
        if include_optional:
            return AiAssistantGoalGet(
                additional_prompt = '',
                ai_assistant_id = 56,
                course_ids = [
                    56
                    ],
                created_at = 56,
                engagement = 56,
                engagement_opt_out_duration = 56,
                engagement_preset = chat_server_connector_v2.models.goal_engagement_preset_get.GoalEngagementPresetGet(
                    created_at = 56, 
                    engagement = 56, 
                    engagement_opt_out_duration = 56, 
                    id = 56, 
                    max_engagement_count = 56, 
                    max_engagement_period = 56, 
                    max_total_engagement_count = 56, 
                    name = '', 
                    order = 56, ),
                engagement_preset_id = 56,
                id = 56,
                interactions_summary = chat_server_connector_v2.models.goal_interactions_summary.GoalInteractionsSummary(
                    is_available = True, 
                    last_engagement_at = 56, 
                    last_opt_out_at = 56, 
                    recent_interaction_count = 56, 
                    total_interaction_count = 56, ),
                is_active = True,
                is_fullfilled = True,
                last_updated_at = 56,
                max_engagement_count = 56,
                max_engagement_period = 56,
                max_total_engagement_count = 56,
                name = '',
                page_url = '',
                primary_course = chat_server_connector_v2.models.course_public.CoursePublic(
                    description = '', 
                    id = 56, 
                    modules = [
                        chat_server_connector_v2.models.course_module_public.CourseModulePublic(
                            id = 56, 
                            lessons = [
                                chat_server_connector_v2.models.module_lesson_public.ModuleLessonPublic(
                                    id = 56, 
                                    title = '', )
                                ], 
                            public_description = '', 
                            short_description = '', 
                            title = '', )
                        ], 
                    payment_type = 'paid', 
                    title = '', 
                    url = '', ),
                primary_course_id = 56
            )
        else:
            return AiAssistantGoalGet(
                additional_prompt = '',
                ai_assistant_id = 56,
                course_ids = [
                    56
                    ],
                created_at = 56,
                engagement = 56,
                engagement_opt_out_duration = 56,
                id = 56,
                is_active = True,
                last_updated_at = 56,
                max_engagement_count = 56,
                max_engagement_period = 56,
                max_total_engagement_count = 56,
                name = '',
        )
        """

    def testAiAssistantGoalGet(self):
        """Test AiAssistantGoalGet"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mentortools Chat API

    Mentortools service for chatting

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from chat_server_connector_v2.models.response_wrapper_chat_settings_get import ResponseWrapperChatSettingsGet

class TestResponseWrapperChatSettingsGet(unittest.TestCase):
    """ResponseWrapperChatSettingsGet unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ResponseWrapperChatSettingsGet:
        """Test ResponseWrapperChatSettingsGet
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ResponseWrapperChatSettingsGet`
        """
        model = ResponseWrapperChatSettingsGet()
        if include_optional:
            return ResponseWrapperChatSettingsGet(
                done = True,
                result = chat_server_connector_v2.models.chat_settings_get.ChatSettingsGet(
                    chat_enabled = True, 
                    dms_enables = True, ),
                error = ''
            )
        else:
            return ResponseWrapperChatSettingsGet(
                done = True,
        )
        """

    def testResponseWrapperChatSettingsGet(self):
        """Test ResponseWrapperChatSettingsGet"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mentortools Chat API

    Mentortools service for chatting

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictFloat, StrictInt
from typing import Any, ClassVar, Dict, List, Optional, Union
from chat_server_connector_v2.models.chat_get_with_members import ChatGetWithMembers
from chat_server_connector_v2.models.chat_message_read import ChatMessageRead
from chat_server_connector_v2.models.chat_session_type import ChatSessionType
from typing import Optional, Set
from typing_extensions import Self
from pydantic_core import to_jsonable_python

class ChatSessionGetWithChatData(BaseModel):
    """
    ChatSessionGetWithChatData
    """ # noqa: E501
    id: StrictInt
    chat_id: StrictInt
    creator_id: StrictInt
    credentials: Dict[str, Any]
    chat_session_type: ChatSessionType
    created_at: StrictInt
    ended_at: Optional[StrictInt] = None
    last_activity_at: StrictInt
    messages: Optional[List[ChatMessageRead]] = None
    chat: ChatGetWithMembers
    tokens_used: Optional[Union[StrictFloat, StrictInt]] = 0.0
    __properties: ClassVar[List[str]] = ["id", "chat_id", "creator_id", "credentials", "chat_session_type", "created_at", "ended_at", "last_activity_at", "messages", "chat", "tokens_used"]

    model_config = ConfigDict(
        validate_by_name=True,
        validate_by_alias=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(to_jsonable_python(self.to_dict()))

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ChatSessionGetWithChatData from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in messages (list)
        _items = []
        if self.messages:
            for _item_messages in self.messages:
                if _item_messages:
                    _items.append(_item_messages.to_dict())
            _dict['messages'] = _items
        # override the default output from pydantic by calling `to_dict()` of chat
        if self.chat:
            _dict['chat'] = self.chat.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ChatSessionGetWithChatData from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "chat_id": obj.get("chat_id"),
            "creator_id": obj.get("creator_id"),
            "credentials": obj.get("credentials"),
            "chat_session_type": obj.get("chat_session_type"),
            "created_at": obj.get("created_at"),
            "ended_at": obj.get("ended_at"),
            "last_activity_at": obj.get("last_activity_at"),
            "messages": [ChatMessageRead.from_dict(_item) for _item in obj["messages"]] if obj.get("messages") is not None else None,
            "chat": ChatGetWithMembers.from_dict(obj["chat"]) if obj.get("chat") is not None else None,
            "tokens_used": obj.get("tokens_used") if obj.get("tokens_used") is not None else 0.0
        })
        return _obj





# coding: utf-8

"""
    Mentortools Chat API

    Mentortools service for chatting

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from chat_server_connector_v2.models.chat_member_get import ChatMemberGet
from chat_server_connector_v2.models.chat_message import ChatMessage
from chat_server_connector_v2.models.chat_type import ChatType
from typing import Optional, Set
from typing_extensions import Self
from pydantic_core import to_jsonable_python

class ChatListGet(BaseModel):
    """
    ChatListGet
    """ # noqa: E501
    id: StrictInt
    uuid: StrictStr
    chat_type: ChatType
    avatar_id: Optional[StrictStr] = None
    name: Optional[StrictStr] = None
    description: Optional[StrictStr] = None
    messaging_enabled: StrictBool
    permalink_enabled: StrictBool
    is_visible: StrictBool
    topic_slug: Optional[StrictStr] = None
    is_muted: Optional[StrictBool] = False
    created_at: StrictInt
    last_updated_at: StrictInt
    members: Optional[List[ChatMemberGet]] = None
    last_message: Optional[ChatMessage] = None
    unread_count: Optional[StrictInt] = 0
    __properties: ClassVar[List[str]] = ["id", "uuid", "chat_type", "avatar_id", "name", "description", "messaging_enabled", "permalink_enabled", "is_visible", "topic_slug", "is_muted", "created_at", "last_updated_at", "members", "last_message", "unread_count"]

    model_config = ConfigDict(
        validate_by_name=True,
        validate_by_alias=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(to_jsonable_python(self.to_dict()))

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ChatListGet from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in members (list)
        _items = []
        if self.members:
            for _item_members in self.members:
                if _item_members:
                    _items.append(_item_members.to_dict())
            _dict['members'] = _items
        # override the default output from pydantic by calling `to_dict()` of last_message
        if self.last_message:
            _dict['last_message'] = self.last_message.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ChatListGet from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "uuid": obj.get("uuid"),
            "chat_type": obj.get("chat_type"),
            "avatar_id": obj.get("avatar_id"),
            "name": obj.get("name"),
            "description": obj.get("description"),
            "messaging_enabled": obj.get("messaging_enabled"),
            "permalink_enabled": obj.get("permalink_enabled"),
            "is_visible": obj.get("is_visible"),
            "topic_slug": obj.get("topic_slug"),
            "is_muted": obj.get("is_muted") if obj.get("is_muted") is not None else False,
            "created_at": obj.get("created_at"),
            "last_updated_at": obj.get("last_updated_at"),
            "members": [ChatMemberGet.from_dict(_item) for _item in obj["members"]] if obj.get("members") is not None else None,
            "last_message": ChatMessage.from_dict(obj["last_message"]) if obj.get("last_message") is not None else None,
            "unread_count": obj.get("unread_count") if obj.get("unread_count") is not None else 0
        })
        return _obj





# coding: utf-8

# flake8: noqa

"""
    Mentortools Chat API

    Mentortools service for chatting

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.2.0+2499956661"

# Define package exports
__all__ = [
    "AdminApi",
    "BotsApi",
    "ChatApiApi",
    "ChatSessionsApi",
    "ChatSettingsApi",
    "ChatsApi",
    "ChatsV2Api",
    "ContactsApi",
    "DefaultApi",
    "ExternalSystemUserApi",
    "FeedbackApi",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "AiAssistantGet",
    "AiAssistantGoalGet",
    "AiAssistantLexiconItem",
    "AssistantFunction",
    "AssistantType",
    "AssistantUsageType",
    "ChatGetWithMembers",
    "ChatGetWithMembersAndMessages",
    "ChatGetWithMembersAndMessagesWithMetadata",
    "ChatListGet",
    "ChatMemberCreateOrUpdate",
    "ChatMemberGet",
    "ChatMemberRole",
    "ChatMemberRoleAdd",
    "ChatMessage",
    "ChatMessageAttachmentCreate",
    "ChatMessageAttachmentRead",
    "ChatMessageAttachmentReadWithMetadata",
    "ChatMessageAttachmentType",
    "ChatMessageCreate",
    "ChatMessageInsert",
    "ChatMessageRead",
    "ChatMessageReadWithMetadata",
    "ChatMessageType",
    "ChatNew",
    "ChatPatch",
    "ChatSessionGet",
    "ChatSessionGetWithChatData",
    "ChatSessionType",
    "ChatSettingsCreateOrUpdate",
    "ChatSettingsGet",
    "ChatType",
    "ChatUpdate",
    "CollectionState",
    "CollectionStatus",
    "ConsumedUnits",
    "Contact",
    "ContactAddress",
    "ConversationStyle",
    "CourseModulePublic",
    "CoursePaymentTypeStrEnum",
    "CoursePublic",
    "ExternalSystemMessage",
    "ExternalSystemType",
    "ExternalSystemUserGet",
    "ExternalSystemUserUpdate",
    "FeedbackCreate",
    "FeedbackRead",
    "FeedbackType",
    "FeedbackWithSessionRead",
    "GoalEngagementPresetGet",
    "GoalInteractionsSummary",
    "HTTPValidationError",
    "KnowledgebaseState",
    "LocationInner",
    "ModuleLessonPublic",
    "ResponseWrapper",
    "ResponseWrapperBool",
    "ResponseWrapperChatGetWithMembersAndMessages",
    "ResponseWrapperChatGetWithMembersAndMessagesWithMetadata",
    "ResponseWrapperChatMessageReadWithMetadata",
    "ResponseWrapperChatSessionGet",
    "ResponseWrapperChatSessionGetWithChatData",
    "ResponseWrapperChatSettingsGet",
    "ResponseWrapperContact",
    "ResponseWrapperExternalSystemUserGet",
    "ResponseWrapperInt",
    "ResponseWrapperListChatListGet",
    "ResponseWrapperListChatMemberGet",
    "ResponseWrapperListChatMessageReadWithMetadata",
    "ResponseWrapperListChatSessionGetWithChatData",
    "ResponseWrapperListContact",
    "ResponseWrapperListFeedbackWithSessionRead",
    "Result",
    "RoleEnum",
    "UsageDataFromFront",
    "UsageDataFromFrontV2",
    "UsageDataV2",
    "ValidationError",
]

# import apis into sdk package
from chat_server_connector_v2.api.admin_api import AdminApi as AdminApi
from chat_server_connector_v2.api.bots_api import BotsApi as BotsApi
from chat_server_connector_v2.api.chat_api_api import ChatApiApi as ChatApiApi
from chat_server_connector_v2.api.chat_sessions_api import ChatSessionsApi as ChatSessionsApi
from chat_server_connector_v2.api.chat_settings_api import ChatSettingsApi as ChatSettingsApi
from chat_server_connector_v2.api.chats_api import ChatsApi as ChatsApi
from chat_server_connector_v2.api.chats_v2_api import ChatsV2Api as ChatsV2Api
from chat_server_connector_v2.api.contacts_api import ContactsApi as ContactsApi
from chat_server_connector_v2.api.default_api import DefaultApi as DefaultApi
from chat_server_connector_v2.api.external_system_user_api import ExternalSystemUserApi as ExternalSystemUserApi
from chat_server_connector_v2.api.feedback_api import FeedbackApi as FeedbackApi

# import ApiClient
from chat_server_connector_v2.api_response import ApiResponse as ApiResponse
from chat_server_connector_v2.api_client import ApiClient as ApiClient
from chat_server_connector_v2.configuration import Configuration as Configuration
from chat_server_connector_v2.exceptions import OpenApiException as OpenApiException
from chat_server_connector_v2.exceptions import ApiTypeError as ApiTypeError
from chat_server_connector_v2.exceptions import ApiValueError as ApiValueError
from chat_server_connector_v2.exceptions import ApiKeyError as ApiKeyError
from chat_server_connector_v2.exceptions import ApiAttributeError as ApiAttributeError
from chat_server_connector_v2.exceptions import ApiException as ApiException

# import models into sdk package
from chat_server_connector_v2.models.ai_assistant_get import AiAssistantGet as AiAssistantGet
from chat_server_connector_v2.models.ai_assistant_goal_get import AiAssistantGoalGet as AiAssistantGoalGet
from chat_server_connector_v2.models.ai_assistant_lexicon_item import AiAssistantLexiconItem as AiAssistantLexiconItem
from chat_server_connector_v2.models.assistant_function import AssistantFunction as AssistantFunction
from chat_server_connector_v2.models.assistant_type import AssistantType as AssistantType
from chat_server_connector_v2.models.assistant_usage_type import AssistantUsageType as AssistantUsageType
from chat_server_connector_v2.models.chat_get_with_members import ChatGetWithMembers as ChatGetWithMembers
from chat_server_connector_v2.models.chat_get_with_members_and_messages import ChatGetWithMembersAndMessages as ChatGetWithMembersAndMessages
from chat_server_connector_v2.models.chat_get_with_members_and_messages_with_metadata import ChatGetWithMembersAndMessagesWithMetadata as ChatGetWithMembersAndMessagesWithMetadata
from chat_server_connector_v2.models.chat_list_get import ChatListGet as ChatListGet
from chat_server_connector_v2.models.chat_member_create_or_update import ChatMemberCreateOrUpdate as ChatMemberCreateOrUpdate
from chat_server_connector_v2.models.chat_member_get import ChatMemberGet as ChatMemberGet
from chat_server_connector_v2.models.chat_member_role import ChatMemberRole as ChatMemberRole
from chat_server_connector_v2.models.chat_member_role_add import ChatMemberRoleAdd as ChatMemberRoleAdd
from chat_server_connector_v2.models.chat_message import ChatMessage as ChatMessage
from chat_server_connector_v2.models.chat_message_attachment_create import ChatMessageAttachmentCreate as ChatMessageAttachmentCreate
from chat_server_connector_v2.models.chat_message_attachment_read import ChatMessageAttachmentRead as ChatMessageAttachmentRead
from chat_server_connector_v2.models.chat_message_attachment_read_with_metadata import ChatMessageAttachmentReadWithMetadata as ChatMessageAttachmentReadWithMetadata
from chat_server_connector_v2.models.chat_message_attachment_type import ChatMessageAttachmentType as ChatMessageAttachmentType
from chat_server_connector_v2.models.chat_message_create import ChatMessageCreate as ChatMessageCreate
from chat_server_connector_v2.models.chat_message_insert import ChatMessageInsert as ChatMessageInsert
from chat_server_connector_v2.models.chat_message_read import ChatMessageRead as ChatMessageRead
from chat_server_connector_v2.models.chat_message_read_with_metadata import ChatMessageReadWithMetadata as ChatMessageReadWithMetadata
from chat_server_connector_v2.models.chat_message_type import ChatMessageType as ChatMessageType
from chat_server_connector_v2.models.chat_new import ChatNew as ChatNew
from chat_server_connector_v2.models.chat_patch import ChatPatch as ChatPatch
from chat_server_connector_v2.models.chat_session_get import ChatSessionGet as ChatSessionGet
from chat_server_connector_v2.models.chat_session_get_with_chat_data import ChatSessionGetWithChatData as ChatSessionGetWithChatData
from chat_server_connector_v2.models.chat_session_type import ChatSessionType as ChatSessionType
from chat_server_connector_v2.models.chat_settings_create_or_update import ChatSettingsCreateOrUpdate as ChatSettingsCreateOrUpdate
from chat_server_connector_v2.models.chat_settings_get import ChatSettingsGet as ChatSettingsGet
from chat_server_connector_v2.models.chat_type import ChatType as ChatType
from chat_server_connector_v2.models.chat_update import ChatUpdate as ChatUpdate
from chat_server_connector_v2.models.collection_state import CollectionState as CollectionState
from chat_server_connector_v2.models.collection_status import CollectionStatus as CollectionStatus
from chat_server_connector_v2.models.consumed_units import ConsumedUnits as ConsumedUnits
from chat_server_connector_v2.models.contact import Contact as Contact
from chat_server_connector_v2.models.contact_address import ContactAddress as ContactAddress
from chat_server_connector_v2.models.conversation_style import ConversationStyle as ConversationStyle
from chat_server_connector_v2.models.course_module_public import CourseModulePublic as CourseModulePublic
from chat_server_connector_v2.models.course_payment_type_str_enum import CoursePaymentTypeStrEnum as CoursePaymentTypeStrEnum
from chat_server_connector_v2.models.course_public import CoursePublic as CoursePublic
from chat_server_connector_v2.models.external_system_message import ExternalSystemMessage as ExternalSystemMessage
from chat_server_connector_v2.models.external_system_type import ExternalSystemType as ExternalSystemType
from chat_server_connector_v2.models.external_system_user_get import ExternalSystemUserGet as ExternalSystemUserGet
from chat_server_connector_v2.models.external_system_user_update import ExternalSystemUserUpdate as ExternalSystemUserUpdate
from chat_server_connector_v2.models.feedback_create import FeedbackCreate as FeedbackCreate
from chat_server_connector_v2.models.feedback_read import FeedbackRead as FeedbackRead
from chat_server_connector_v2.models.feedback_type import FeedbackType as FeedbackType
from chat_server_connector_v2.models.feedback_with_session_read import FeedbackWithSessionRead as FeedbackWithSessionRead
from chat_server_connector_v2.models.goal_engagement_preset_get import GoalEngagementPresetGet as GoalEngagementPresetGet
from chat_server_connector_v2.models.goal_interactions_summary import GoalInteractionsSummary as GoalInteractionsSummary
from chat_server_connector_v2.models.http_validation_error import HTTPValidationError as HTTPValidationError
from chat_server_connector_v2.models.knowledgebase_state import KnowledgebaseState as KnowledgebaseState
from chat_server_connector_v2.models.location_inner import LocationInner as LocationInner
from chat_server_connector_v2.models.module_lesson_public import ModuleLessonPublic as ModuleLessonPublic
from chat_server_connector_v2.models.response_wrapper import ResponseWrapper as ResponseWrapper
from chat_server_connector_v2.models.response_wrapper_bool import ResponseWrapperBool as ResponseWrapperBool
from chat_server_connector_v2.models.response_wrapper_chat_get_with_members_and_messages import ResponseWrapperChatGetWithMembersAndMessages as ResponseWrapperChatGetWithMembersAndMessages
from chat_server_connector_v2.models.response_wrapper_chat_get_with_members_and_messages_with_metadata import ResponseWrapperChatGetWithMembersAndMessagesWithMetadata as ResponseWrapperChatGetWithMembersAndMessagesWithMetadata
from chat_server_connector_v2.models.response_wrapper_chat_message_read_with_metadata import ResponseWrapperChatMessageReadWithMetadata as ResponseWrapperChatMessageReadWithMetadata
from chat_server_connector_v2.models.response_wrapper_chat_session_get import ResponseWrapperChatSessionGet as ResponseWrapperChatSessionGet
from chat_server_connector_v2.models.response_wrapper_chat_session_get_with_chat_data import ResponseWrapperChatSessionGetWithChatData as ResponseWrapperChatSessionGetWithChatData
from chat_server_connector_v2.models.response_wrapper_chat_settings_get import ResponseWrapperChatSettingsGet as ResponseWrapperChatSettingsGet
from chat_server_connector_v2.models.response_wrapper_contact import ResponseWrapperContact as ResponseWrapperContact
from chat_server_connector_v2.models.response_wrapper_external_system_user_get import ResponseWrapperExternalSystemUserGet as ResponseWrapperExternalSystemUserGet
from chat_server_connector_v2.models.response_wrapper_int import ResponseWrapperInt as ResponseWrapperInt
from chat_server_connector_v2.models.response_wrapper_list_chat_list_get import ResponseWrapperListChatListGet as ResponseWrapperListChatListGet
from chat_server_connector_v2.models.response_wrapper_list_chat_member_get import ResponseWrapperListChatMemberGet as ResponseWrapperListChatMemberGet
from chat_server_connector_v2.models.response_wrapper_list_chat_message_read_with_metadata import ResponseWrapperListChatMessageReadWithMetadata as ResponseWrapperListChatMessageReadWithMetadata
from chat_server_connector_v2.models.response_wrapper_list_chat_session_get_with_chat_data import ResponseWrapperListChatSessionGetWithChatData as ResponseWrapperListChatSessionGetWithChatData
from chat_server_connector_v2.models.response_wrapper_list_contact import ResponseWrapperListContact as ResponseWrapperListContact
from chat_server_connector_v2.models.response_wrapper_list_feedback_with_session_read import ResponseWrapperListFeedbackWithSessionRead as ResponseWrapperListFeedbackWithSessionRead
from chat_server_connector_v2.models.result import Result as Result
from chat_server_connector_v2.models.role_enum import RoleEnum as RoleEnum
from chat_server_connector_v2.models.usage_data_from_front import UsageDataFromFront as UsageDataFromFront
from chat_server_connector_v2.models.usage_data_from_front_v2 import UsageDataFromFrontV2 as UsageDataFromFrontV2
from chat_server_connector_v2.models.usage_data_v2 import UsageDataV2 as UsageDataV2
from chat_server_connector_v2.models.validation_error import ValidationError as ValidationError

